--[[
	Project....: BGRep
	File.......: BGRep.lua
	Description: MainFrame for BGRep
	Version....: 1.3
	Created....: December 23rd 2015 (Azhtyhx)
	Updated....: December 26th 2015 (Azhtyhx)
]]

local addonName, BGRep = ...
BGRep = LibStub("AceAddon-3.0"):NewAddon(BGRep, addonName, "AceEvent-3.0")
local db

local warsongFlags = 0
local arathiTicks = 0
local warsongID = 0
local arathiID = 0
local maxValue = 42000

-- Default DB settings
local defaults = {
	profile = {
		bgrepPoint = "CENTER",
		bgrepRelativeTo = nil,
		bgrepRelativePoint = "CENTER",
		bgrepxOfs = 0,
		bgrepyOfs = 0,
	}
}

function BGRep:FactionCheck()
	englishFaction, localizedFaction = UnitFactionGroup(UnitName("player"))
	if englishFaction == "Horde" then
		warsongID = 889
		arathiID = 510
	elseif englishFaction == "Alliance" then
		warsongID = 890
		arathiID = 509
	end
end

function BGRep:OnDragStart(arg1)
	if arg1 == "LeftButton" then
		self:StartMoving()
	end
end

function BGRep:OnDragStop()
	self:StopMovingOrSizing()
	
	point, relativeTo, relativePoint, xOfs, yOfs = BGRepFrame:GetPoint()
	
	db.bgrepPoint = point
	db.bgrepRelativeTo = relativeTo
	db.bgrepRelativePoint = relativePoint
	db.bgrepxOfs = xOfs
	db.bgrepyOfs = yOfs
end

function BGRep:SetupFrame()
	BGRepFrame = CreateFrame("Frame", "BGRepFrame", UIParent)
	BGRepFrame:SetMovable(true)
	BGRepFrame:EnableMouse(true)
	BGRepFrame:RegisterForDrag("LeftButton")
	BGRepFrame:SetScript("OnMouseDown", BGRep.OnDragStart)
	BGRepFrame:SetScript("OnMouseUp", BGRep.OnDragStop)
	
	BGRepFrame:SetPoint(db.bgrepPoint, db.bgrepRelativeTo, db.bgrepRelativePoint, db.bgrepxOfs, db.bgrepyOfs);
	BGRepFrame:SetWidth(128);
	BGRepFrame:SetHeight(45);
	local tex = BGRepFrame:CreateTexture("ARTWORK");
	tex:SetAllPoints();
	tex:SetTexture(1.0, 0.5, 0); tex:SetAlpha(0.5);
	
	--Warsong Gulch Text
	BGRepFrame.Warsong = BGRepFrame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	BGRepFrame.Warsong:SetPoint("TOP", BGRepFrame, "TOP", 0, -5)
	BGRepFrame.Warsong:SetTextColor(1.0, 1.0, 1.0)
	BGRepFrame.Warsong:SetText("Warsong Gulch: " .. warsongFlags)
	
	--Arathi Basin Text
	BGRepFrame.Arathi = BGRepFrame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	BGRepFrame.Arathi:SetPoint("TOP", BGRepFrame, "TOP", 0, -25)
	BGRepFrame.Arathi:SetTextColor(1.0, 1.0, 1.0)
	BGRepFrame.Arathi:SetText("Arathi Basin: " .. arathiTicks)
	
	BGRepFrame:Hide()
end

function BGRep:FlagUpdate()
	local name, description, standingID, barMin, barMax, barValue = GetFactionInfoByID(warsongID)
	warsongFlags = math.floor((maxValue - barValue) / 100 + 0.5)
	
	name, description, standingID, barMin, barMax, barValue = GetFactionInfoByID(arathiID)
	arathiTicks = math.floor((maxValue - barValue) / 50 + 0.5)
	
	BGRepFrame.Warsong:SetText("Warsong Gulch: " .. warsongFlags)
	BGRepFrame.Arathi:SetText("Arathi Basin: " .. arathiTicks)
end

function BGRep:OnInitialize()
	-- Initialize the DB
	self.db = LibStub("AceDB-3.0"):New("BGRepDB", defaults, true)
	db = self.db.profile
	
	BGRep.SetupFrame()
end

function BGRep:Enable()
	if not SecondTime then
		BGRep.FactionCheck()
		BGRep.FlagUpdate()
		SecondTime = true
	end
	BGRep:RegisterEvent("CHAT_MSG_COMBAT_FACTION_CHANGE", BGRep.FlagUpdate)
	BGRepFrame:Show()
end

function BGRep:Disable()
	BGRep:UnregisterEvent("CHAT_MSG_COMBAT_FACTION_CHANGE", BGRep.FlagUpdate)
	BGRepFrame:Hide()
end

function BGRep:Toggle(arg1)
	if arg1 == "LeftButton" then
		if BGRepFrame:IsShown() then
			BGRep:Disable()
		else
			BGRep:Enable()
		end
	elseif arg1 == "RightButton" then
		print("RightButton")
	end
end